@@ -57,8 +57,8 @@ inum.data.frame <- function(object, nmax = 20, ignore = NULL, total = FALSE,
             cc[is.na(cc)] <- TRUE
             if (any(!cc)) {
                 sDF <- sDF[cc,,drop = FALSE]
-                ret[!cc] <- 0L
-                ret <- unclass(factor(ret)) - 1L
+                rownames(sDF) <- 1:nrow(sDF)
+                ret <- ret - 1L
             }
         }  
 
@@ -92,7 +92,11 @@ inum.data.frame <- function(object, nmax = 20, ignore = NULL, total = FALSE,
                 ux <- unique(quantile(x, prob = 1:(nmax - 1L) / nmax, 
                                       na.rm = TRUE))
             ux <- ux[ux < xmax]
-            tol <- min(diff(sort(ux))) ### sqrt(.Machine$double.eps)
+            if (length(ux) > 1L) {
+                tol <- max(min(diff(sort(ux))), sqrt(.Machine$double.eps))
+            } else {
+                tol <- sqrt(.Machine$double.eps)
+            }
             ix <- interval(x, breaks = c(xmin - tol, ux, xmax))
             if (all(as.interval != v)) {
                 if (length(oux) <= nmax) {
